==> nextcloud-app-deck-1%3A1.7.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/uk.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Ви створили нову дошку {board}",
    "{user} has created a new board {board}" : "{user} створив нову дошку {board}",
    "You have deleted the board {board}" : "Ви вилучили дошку {board}",
    "{user} has deleted the board {board}" : "{user} вилучив дошку {board}",
    "You have restored the board {board}" : "Ви відновили дошку {board}",
    "{user} has restored the board {board}" : "{user} відновив дошку {board}",
    "You have shared the board {board} with {acl}" : "Ви поділилися дошкою {board} з {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} поділився дошкою {board} з {acl}",
    "You have removed {acl} from the board {board}" : "Ви вилучили {acl} з дошки {board}",
    "{user} has removed {acl} from the board {board}" : "{user} вилучив {acl} з дошки {board}",
    "You have renamed the board {before} to {board}" : "Ви перейменували дошку з {before} у {board}",
    "Deck" : "Колода",
    "Changes in the <strong>Deck app</strong>" : "Зміни у застосунку <strong>Колода</strong>",
    "Personal" : "Особисте",
    "Finished" : "Завершено",
    "To review" : "На перегляд",
    "Action needed" : "Потребує дій",
    "Later" : "Пізніше",
    "copy" : "копіювати",
    "To do" : "Заплановано",
    "Doing" : "Виконується",
    "Done" : "Готово",
    "Example Task 3" : "Приклад завдання 3",
    "Example Task 2" : "Приклад завдання 2",
    "Example Task 1" : "Приклад завдання 1",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
    "The file was only partially uploaded" : "Файл завантажено лише частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутня тека для тимчасових файлів",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "Card details" : "Деталі картки",
    "Add board" : "Додати дошку",
    "Select the board to link to a project" : "Виберіть дошку для прив'зки до проєкту",
    "Search by board title" : "Шукати за назвою дошки",
    "Select board" : "Вибрати дошку",
    "Select a board" : "Вибрати дошку",
    "Select a list" : "Виберіть список",
    "Cancel" : "Скасувати",
    "Select a card" : "Вибрати картку",
    "Select the card to link to a project" : "Виберіть картку для прив'язки до проєкту",
    "Link to card" : "Прив'язати до картки",
    "File already exists" : "Файл вже існує",
    "A file with the name {filename} already exists." : "Файл {filename} вже існує.",
    "Do you want to overwrite it?" : "Дійсно перезаписати файл?",
    "Overwrite file" : "Перезаписати файл",
    "Keep existing file" : "Зберегти поточний файл",
    "This board is read only" : "Дошка тільки для читання",
    "Drop your files to upload" : "Пересуньте файли сюди для завантаження",
    "Add card" : "Додати картку",
    "Archived cards" : "Архівні картки",
    "Add list" : "Додати список",
    "List name" : "Назва списку",
    "Apply filter" : "Відфільтрувати",
    "Filter by tag" : "Відібрати за позначками",
    "Filter by assigned user" : "Відібрати за призначеним користувачем",
    "Unassigned" : "Скасовано призначення",
    "Filter by due date" : "Відібрати за датою завершення",
    "Overdue" : "Протерміновано",
    "Next 7 days" : "Наступні 7 днів",
    "Next 30 days" : "Наступні 30 днів",
    "No due date" : "Без дати завершення",
    "Clear filter" : "Очистити фільтр",
    "Hide archived cards" : "Приховати архівні картки",
    "Show archived cards" : "Показати архівні картки",
    "Toggle compact mode" : "Перемкнути компактний вигляд",
    "Details" : "Деталі",
    "Loading board" : "Завантаження дошки",
    "Board not found" : "Дошку не знайдено",
    "Sharing" : "Поділитись",
    "Tags" : "Теги",
    "Deleted items" : "Вилучені елементи",
    "Timeline" : "Дії",
    "Deleted lists" : "Вилучені списки",
    "Undo" : "Скасувати",
    "Deleted cards" : "Вилучені картки",
    "Share board with a user, group or circle …" : "Поділитися дошкою з користувачем, групою або колом...",
    "Board owner" : "Власник дошки",
    "(Group)" : "(група)",
    "(Circle)" : "(Коло)",
    "Can edit" : "Можна редагувати",
    "Can share" : "Can share",
    "Can manage" : "Може керувати",
    "Delete" : "Вилучити",
    "Add a new list" : "Додати новий список",
    "Delete list" : "Вилучити список",
    "Add a new card" : "Додати нову картку",
    "Edit" : "Редагувати",
    "Add a new tag" : "Додати нову позначку",
    "title and color value must be provided" : "потрібно зазначити назву та колір",
    "Members" : "Учасники",
    "Add this attachment" : "Долучити вкладення",
    "Delete Attachment" : "Забрати вкладення",
    "Restore Attachment" : "Відновити вкладення",
    "Attachments" : "Вкладення",
    "Comments" : "Коментарі",
    "Modified" : "Змінено",
    "Created" : "Створено",
    "Assign a tag to this card…" : "Додати позначку до цієї картки",
    "Assign to users" : "Призначити користувачам",
    "Assign to users/groups/circles" : "Призначити користувачам/групам/колам",
    "Assign a user to this card…" : "Призначити користувачеві цю картку",
    "Due date" : "Протягом",
    "Set a due date" : "Встановити дату завершення",
    "Remove due date" : "Вилучити до",
    "Select Date" : "Вкажіть дату",
    "Today" : "Сьогодні",
    "Tomorrow" : "Завтра",
    "Save" : "Зберегти",
    "In reply to" : "У відповідь",
    "Reply" : "Відповісти",
    "Update" : "Оновлення",
    "Description" : "Опис",
    "(Unsaved)" : "(Не збережено)",
    "(Saving…)" : "(Зберігання...)",
    "Formatting help" : "Форматування довідки",
    "Edit description" : "Редагувати опис",
    "View description" : "Переглянути опис",
    "Add Attachment" : "Долучити вкладення",
    "Choose attachment" : "Вибрати вкладення",
    "(group)" : "(група)",
    "Assign to me" : "Призначити мені",
    "Move card" : "Пересунути картку",
    "Unarchive card" : "Розархівувати картку",
    "Archive card" : "Архівувати картку",
    "Delete card" : "Вилучити картку",
    "Move card to another board" : "Перемістити картку до іншої дошки",
    "seconds ago" : "секунд тому",
    "All boards" : "Усі дошки",
    "Archived boards" : "Архівні дошки",
    "Shared with you" : "Вам надано доступ",
    "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
    "Board details" : "Деталі дошки",
    "Edit board" : "Редагувати дошку",
    "Board {0} deleted" : "Дошку {0} вилучено",
    "An error occurred" : "Виникла помилка",
    "Delete the board?" : "Вилучити дошку?",
    "Link to a board" : "Прив'язати до дошки",
    "Link to a card" : "Прив'язати до картки",
    "Something went wrong" : "От халепа!",
    "Maximum file size of {size} exceeded" : "Досягнуто максимальний розмір файлу {size}",
    "This week" : "Цього тижня"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-deck-1%3A1.7.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/uk.js <==
OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "Ви створили нову дошку {board}",
    "{user} has created a new board {board}" : "{user} створив нову дошку {board}",
    "You have deleted the board {board}" : "Ви вилучили дошку {board}",
    "{user} has deleted the board {board}" : "{user} вилучив дошку {board}",
    "You have restored the board {board}" : "Ви відновили дошку {board}",
    "{user} has restored the board {board}" : "{user} відновив дошку {board}",
    "You have shared the board {board} with {acl}" : "Ви поділилися дошкою {board} з {acl}",
    "{user} has shared the board {board} with {acl}" : "{user} поділився дошкою {board} з {acl}",
    "You have removed {acl} from the board {board}" : "Ви вилучили {acl} з дошки {board}",
    "{user} has removed {acl} from the board {board}" : "{user} вилучив {acl} з дошки {board}",
    "You have renamed the board {before} to {board}" : "Ви перейменували дошку з {before} у {board}",
    "Deck" : "Колода",
    "Changes in the <strong>Deck app</strong>" : "Зміни у застосунку <strong>Колода</strong>",
    "Personal" : "Особисте",
    "Finished" : "Завершено",
    "To review" : "На перегляд",
    "Action needed" : "Потребує дій",
    "Later" : "Пізніше",
    "copy" : "копіювати",
    "To do" : "Заплановано",
    "Doing" : "Виконується",
    "Done" : "Готово",
    "Example Task 3" : "Приклад завдання 3",
    "Example Task 2" : "Приклад завдання 2",
    "Example Task 1" : "Приклад завдання 1",
    "The file was uploaded" : "Файл завантажено",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Файл для завантаження перевищує параметр upload_max_filesize у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
    "The file was only partially uploaded" : "Файл завантажено лише частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутня тека для тимчасових файлів",
    "Could not write file to disk" : "Неможливо записати файл на диск",
    "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
    "Card not found" : "Картку не знайдено",
    "Card details" : "Деталі картки",
    "Add board" : "Додати дошку",
    "Select the board to link to a project" : "Виберіть дошку для прив'зки до проєкту",
    "Search by board title" : "Шукати за назвою дошки",
    "Select board" : "Вибрати дошку",
    "Select a board" : "Вибрати дошку",
    "Select a list" : "Виберіть список",
    "Cancel" : "Скасувати",
    "Close" : "закрити",
    "Select a card" : "Вибрати картку",
    "Select the card to link to a project" : "Виберіть картку для прив'язки до проєкту",
    "Link to card" : "Прив'язати до картки",
    "File already exists" : "Файл вже існує",
    "A file with the name {filename} already exists." : "Файл {filename} вже існує.",
    "Do you want to overwrite it?" : "Дійсно перезаписати файл?",
    "Overwrite file" : "Перезаписати файл",
    "Keep existing file" : "Зберегти поточний файл",
    "This board is read only" : "Дошка тільки для читання",
    "Drop your files to upload" : "Пересуньте файли сюди для завантаження",
    "Add card" : "Додати картку",
    "Archived cards" : "Архівні картки",
    "Add list" : "Додати список",
    "List name" : "Назва списку",
    "Apply filter" : "Відфільтрувати",
    "Filter by tag" : "Відібрати за позначками",
    "Filter by assigned user" : "Відібрати за призначеним користувачем",
    "Unassigned" : "Скасовано призначення",
    "Filter by due date" : "Відібрати за датою завершення",
    "Overdue" : "Протерміновано",
    "Next 7 days" : "Наступні 7 днів",
    "Next 30 days" : "Наступні 30 днів",
    "No due date" : "Без дати завершення",
    "Clear filter" : "Очистити фільтр",
    "Hide archived cards" : "Приховати архівні картки",
    "Show archived cards" : "Показати архівні картки",
    "Toggle compact mode" : "Перемкнути компактний вигляд",
    "Details" : "Деталі",
    "Loading board" : "Завантаження дошки",
    "Board not found" : "Дошку не знайдено",
    "Sharing" : "Поділитись",
    "Tags" : "Теги",
    "Deleted items" : "Вилучені елементи",
    "Timeline" : "Дії",
    "Deleted lists" : "Вилучені списки",
    "Undo" : "Скасувати",
    "Deleted cards" : "Вилучені картки",
    "Share board with a user, group or circle …" : "Поділитися дошкою з користувачем, групою або колом...",
    "Board owner" : "Власник дошки",
    "(Group)" : "(група)",
    "(Circle)" : "(Коло)",
    "Can edit" : "Можна редагувати",
    "Can share" : "Can share",
    "Can manage" : "Може керувати",
    "Owner" : "Власник",
    "Delete" : "Вилучити",
    "Transfer" : "Передати",
    "Add a new list" : "Додати новий список",
    "Delete list" : "Вилучити список",
    "Add a new card" : "Додати нову картку",
    "Edit" : "Редагувати",
    "Add a new tag" : "Додати нову позначку",
    "title and color value must be provided" : "потрібно зазначити назву та колір",
    "Members" : "Учасники",
    "Upload new files" : "Додати файл",
    "Share from Files" : "Відкрити Файли",
    "Add this attachment" : "Долучити вкладення",
    "Download" : "Завантажити",
    "Delete Attachment" : "Забрати вкладення",
    "Restore Attachment" : "Відновити вкладення",
    "File to share" : "Виберіть файл для надання доступу",
    "Invalid path selected" : "Вибрано неправильний шлях",
    "Attachments" : "Вкладення",
    "Comments" : "Коментарі",
    "Modified" : "Змінено",
    "Created" : "Створено",
    "Assign a tag to this card…" : "Додати позначку до цієї картки",
    "Assign to users" : "Призначити користувачам",
    "Assign to users/groups/circles" : "Призначити користувачам/групам/колам",
    "Assign a user to this card…" : "Призначити користувачеві цю картку",
    "Due date" : "Протягом",
    "Set a due date" : "Встановити дату завершення",
    "Remove due date" : "Вилучити до",
    "Select Date" : "Вкажіть дату",
    "Today" : "Сьогодні",
    "Tomorrow" : "Завтра",
    "Next week" : "Наступний тиждень",
    "Next month" : "Наступний місяць",
    "Save" : "Зберегти",
    "In reply to" : "У відповідь",
    "Cancel reply" : "Скасувати відповідь",
    "Reply" : "Відповісти",
    "Update" : "Оновлення",
    "Description" : "Опис",
    "(Unsaved)" : "(Не збережено)",
    "(Saving…)" : "(Зберігання...)",
    "Formatting help" : "Форматування довідки",
    "Edit description" : "Редагувати опис",
    "View description" : "Переглянути опис",
    "Add Attachment" : "Долучити вкладення",
    "Choose attachment" : "Вибрати вкладення",
    "(group)" : "(група)",
    "Assign to me" : "Призначити мені",
    "Move card" : "Пересунути картку",
    "Unarchive card" : "Розархівувати картку",
    "Archive card" : "Архівувати картку",
    "Delete card" : "Вилучити картку",
    "Move card to another board" : "Перемістити картку до іншої дошки",
    "seconds ago" : "секунд тому",
    "All boards" : "Усі дошки",
    "Archived boards" : "Архівні дошки",
    "Shared with you" : "Вам надано доступ",
    "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
    "Board details" : "Деталі дошки",
    "Edit board" : "Редагувати дошку",
    "Clone board" : "Копіювати дошку",
    "Unarchive board" : "Розархівувати дошку",
    "Archive board" : "Архівувати дошку",
    "No notifications" : "Немає сповіщень",
    "Delete board" : "Вилучити дошку",
    "Board {0} deleted" : "Дошку {0} вилучено",
    "An error occurred" : "Виникла помилка",
    "Delete the board?" : "Вилучити дошку?",
    "Link to a board" : "Прив'язати до дошки",
    "Link to a card" : "Прив'язати до картки",
    "Something went wrong" : "От халепа!",
    "Maximum file size of {size} exceeded" : "Досягнуто максимальний розмір файлу {size}",
    "Share" : "Поділитися",
    "This week" : "Цього тижня"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
